# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/pmlo/mpol/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Pmlo\\Mpol\\": "packages/pmlo/mpol/src",
            "Pmlo\\Mpol\\Seeders\\": "packages/pmlo/mpol/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Pmlo\Mpol\Providers\MpolServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Mpol'  => Pmlo\Mpol\Facades\Mpol::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Pmlo\\Mpol\\Seeders\\MpolTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Pmlo\Mpol\Providers\MpolServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Pmlo\Mpol\Providers\MpolServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Pmlo\Mpol\Providers\MpolServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/mpol/{modulename}

**User**

    http://path-to-route-folder/user/mpol/{modulename}

**Public**

    http://path-to-route-folder/mpols


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/mpol/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/mpol/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/mpol/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/mpol/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/mpol/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/mpol/{modulename}/{slug}
    METHOD: GET